#!/bin/sh

details="$1"; [ "$1" = "" ] && details="n"
mode="$2"; [ "$2" = "" ] && mode="m"
year="$3"; [ "$3" = "" ] && year="??"; [ "$3" = "xx" ] && year="??"
month="$4"; [ "$4" = "" ] && month="??"; [ "$4" = "xx" ] && month="??"
day="$5"; [ "$5" = "" ] && day="??"; [ "$5" = "xx" ] && day="??"

#####get configuration data#####
if [ -f "./data/config" ]; then
  start="$(cat "./data/config"|grep "wrt_stbill"|cut -d '=' -f2)"
  limit1="$(cat "./data/config"|grep "wrt_limit1"|cut -d '=' -f2)"
  limit2="$(cat "./data/config"|grep "wrt_limit2"|cut -d '=' -f2)"
  unitdv="$(cat "./data/config"|grep "wrt_unitdv"|cut -d '=' -f2)"
fi
if [ "$start" = "" ]; then
  start="01"
fi

if [ "$limit1" = "" ]; then
  limit1="0"
fi

if [ "$limit2" = "" ]; then
  limit2="0"
fi
if [ "$unitdv" = "" ]; then
  unitdv="1048576"
fi

#####monthly traffic data#####
if [ "$mode" = "m" ]; then
  day="??"
  echo "<h3>Month 20$year/$month:</h3>"
  listdays=$(find ./data -name "$year$month$day" | sort)
fi
#####by billing period#####
if [ "$mode" = "b" ]; then
  pmonth="$(expr $month - 1)"
  nmonth="$(expr $month + 1)"
  pyear="$year"
  nyear="$year"

  [ "$pmonth" -lt "1" ] && pmonth="12" && pyear="$(expr $year - 1)"
  [ "$pyear" -lt "0" ] && pyear="99"
  [ "$nmonth" -gt "12" ] && nmonth="01" && nyear="$(expr $year + 1)"
  [ "$nyear" -gt "99" ] && nyear="00"
  [ "$(echo "$pmonth" | wc -c)" -lt 3 ] && pmonth="0$pmonth"
  [ "$(echo "$pyear" | wc -c)" -lt 3 ] && pyear="0$pyear"
  [ "$(echo "$nmonth" | wc -c)" -lt 3 ] && nmonth="0$nmonth"
  [ "$(echo "$nyear" | wc -c)" -lt 3 ] && nyear="0$nyear"

  ######calculate all days of current billing period#####
  if [ "$day" -lt "$start" ]; then
    if [ "$pmonth" = "04" ] || [ "$pmonth" = "06" ] || [ "$pmonth" = "09" ] || [ "$pmonth" = "11" ]; then
      bildays="30"
    elif  [ "$pmonth" = "02" ]; then
      bildays="29"
    else
      bildays="31"
    fi
    
    echo "<h3>Billing period beginning at ${start}/${pmonth}/20${pyear}</h3>"
    listdays=$(echo $pyear $pmonth $start $bildays | awk '{for (j=$3;j<=$4;j++) printf "./data/%02d%0.2d%02d\n",$1,$2,j}')
    listdays="$listdays $(echo $year $month $start | awk '{for (j=01;j<$3;j++) printf "./data/%02d%0.2d%02d\n",$1,$2,j}')"
  else
    if [ "$month" = "04" ] || [ "$month" = "06" ] || [ "$month" = "09" ] || [ "$month" = "11" ]; then
      bildays="30"
    elif  [ "$month" = "02" ]; then
      bildays="29"
    else
      bildays="31"
    fi
    
    echo "<h3>Billing period beginning at ${start}/${month}/20${year}</h3>"
    listdays=$(echo $year $month $start $bildays | awk '{for (j=$3;j<=$4;j++) printf "./data/%02d%0.2d%02d\n",$1,$2,j}')
    listdays="$listdays $(echo $nyear $nmonth $start | awk '{for (j=01;j<$3;j++) printf "./data/%02d%0.2d%02d\n",$1,$2,j}')"
  fi
fi

#####yearly traffic data#####
if [ "$mode" = "y" ]; then
  month="??"
  day="??"
  echo "<h3>Year 20$year :</h3>"
  listdays=$(find ./data -name "$year$month$day" | sort)
fi

#####detailed listing#####
if [ "$details" = "y" ]; then
  echo "<table id=\"tabtr\"><tr><td>Day</td><td>Download</td><td>Upload</td></tr>"
fi

rm ./data/tot* 2> /dev/null

#####calculate traffic sum#####
for daylog in $listdays
do
  if [ -f "$daylog" ]; then 
    daydw=`sed -n '1,1p' $daylog`
    dayup=`sed -n '2,2p' $daylog`
  
    if [ "$details" = "y" ]; then
      echo "<tr>"
      echo "<td>`basename $daylog`</td>"
      echo "<td>$(echo $daydw $unitdv | awk '{print $1 / $2}') MB</td>"
      echo "<td>$(echo $dayup $unitdv | awk '{print $1 / $2}') MB</td>"
      echo "</tr>"
    fi
    
    totdw=$(echo $totdw $daydw | awk '{print $1 + $2}')
    totup=$(echo $totup $dayup | awk '{print $1 + $2}')
    let "cntdays+=1"
     
    echo "$totdw" > ./data/totdw
    echo "$totup" > ./data/totup
  fi
done

if [ ! -f ./data/totdw ]; then
  echo "<table id=\"tabtr\"><tr><td>"
  echo "No data available!"
  echo "</td></tr></table>"
  if [ "$details" = "y" ]; then
    echo "</table>"
  fi
  exit
fi

#####get result and adjust units#####
totdw=$(cat ./data/totdw)
totup=$(cat ./data/totup)
totbw=$(echo $totdw $totup | awk '{print $1 + $2}')
totdw=$(echo $totdw $unitdv | awk '{print $1 / $2}')
totup=$(echo $totup $unitdv | awk '{print $1 / $2}')
totbw=$(echo $totbw $unitdv | awk '{print $1 / $2}')

if [ "$details" = "y" ]; then
  echo "<tr class=\"mark\"><td>Total</td><td>$totdw MB</td><td>$totup MB</td><td>$totbw MB</td></tr></table>"
fi

#####print result without details#####
if [ "$details" != "y" ]; then 
  echo "<table id=\"tabtr\">"
  echo "<tr><td>Download</td><td>$totdw MB</td></tr>"
  echo "<tr><td>Upload</td><td>$totup MB</td></tr>"
  echo "<tr class=\"mark\"><td>Total</td><td>$totbw MB</td></tr>"
  echo "</table>"
fi

#####shwow billing period graph#####
if [ "$mode" = "b" ]; then
  totbw=$(echo "$totbw" | cut -d '.' -f1)
  step=$(echo $limit2 100 | awk '{print $1 / $2}' | cut -d '.' -f1)
  
  echo "<br/><table id=\"bpgraph\"><tr>"

  if [ "$totbw" -lt "$limit2" ]; then
    totbw_sc=$(echo $totbw $step | awk '{print $1 / $2}' | cut -d '.' -f1)
  else
    totbw_sc="100"
  fi
  echo "<td id=\"bpgraphtd1\" style=\"width: ${totbw_sc}%;\"></td>"

  if [ "$totbw" -lt "$limit1" ]; then
    limit1_df=$(echo $limit1 $totbw | awk '{print $1 - $2}')
    limit1_sc=$(echo $limit1_df $step | awk '{print $1 / $2}' | cut -d '.' -f1)
  echo "<td id=\"bpgraphtd2\" style=\"width: ${limit1_sc}%;\"></td>"
  else
    limit1_sc="0"
  fi

  if [ "$totbw" -lt "$limit2" ] && [ "$limit1" -lt "$limit2" ]; then
    limit2_sc=$(echo 100 $totbw_sc | awk '{print $1 - $2}')
    limit2_sc=$(echo $limit2_sc $limit1_sc | awk '{print $1 - $2}')
    echo "<td id=\"bpgraphtd3\" style=\"width: ${limit2_sc}%;\"></td>"
  else
    limit2_sc="0"
  fi
  
  echo "</tr></table>"
  
  echo "(traffic so far: ${totbw} MB, limit 1: ${limit1} MB, limit 2: ${limit2} MB)<br/><br/>"
 
  avgcurr=$(echo $totbw $cntdays | awk '{print $1 / $2}' | cut -d '.' -f1)
  predict=$(echo $avgcurr $bildays | awk '{print $1 * $2}')
  
  avglim1=$(echo $limit1 $bildays | awk '{print $1 / $2}' | cut -d '.' -f1)
  avglim2=$(echo $limit2 $bildays | awk '{print $1 / $2}' | cut -d '.' -f1)
  
  remdays=$(echo $bildays $cntdays | awk '{print $1 - $2}')
  diflim1=$(echo $limit1 $totbw | awk '{print $1 - $2}')
  diflim2=$(echo $limit2 $totbw | awk '{print $1 - $2}')
  remlim1=$(echo $diflim1 $remdays | awk '{print $1 / $2}' | cut -d '.' -f1)
  remlim2=$(echo $diflim2 $remdays | awk '{print $1 / $2}' | cut -d '.' -f1)

  echo "<table id=\"tabtr\">" 
  echo "<tr class=\"mark\"><td>Average traffic per day so far: $avgcurr MB</td>"
  echo "<td>Traffic prediction for this billing period: $predict MB</td></tr>"
  echo "<tr><td>Remaining average traffic per day to meet limit 1: $remlim1 MB</td>"
  echo "<td>Remaining average traffic per day to meet limit 2: $remlim2 MB</td></tr>"
  echo "<tr><td>Optimum average traffic per day to meet limit 1: $avglim1 MB</td>"
  echo "<td>Optimum average traffic per day to meet limit 2: $avglim2 MB</td></tr>"
  echo "</table>"
fi
